==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPaneCloseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDetailDescription } from "./WebPaneCloseEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDetailDescriptionMetadata.c(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneCloseEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
            WebContentPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Array:WebContentPaneDescription:ContentPane");
        }
        static d(a) {
            WebPaneCloseEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebPaneCloseEventArgsDetail", () => new WebPaneCloseEventArgsDetailDescription());
            a.ab("WebPaneCloseEventArgsDetail", WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDetailDescriptionMetadata, 'WebPaneCloseEventArgsDetailDescriptionMetadata');
    WebPaneCloseEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebPaneCloseEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneCloseEventArgsDetailDescription } from "./WebPaneCloseEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebPaneCloseEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneCloseEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneCloseEventArgsDetailDescriptionMetadata.a == null) {
                WebPaneCloseEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneCloseEventArgsDetailDescriptionMetadata.c(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebPaneCloseEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPaneCloseEventArgsDetailDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneCloseEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        }
        static d(a) {
            WebPaneCloseEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebPaneCloseEventArgsDetail", () => new WebPaneCloseEventArgsDetailDescription());
            a.ad("WebPaneCloseEventArgsDetail", WebPaneCloseEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebPaneCloseEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneCloseEventArgsDetailDescriptionMetadata, 'WebPaneCloseEventArgsDetailDescriptionMetadata');
    WebPaneCloseEventArgsDetailDescriptionMetadata.a = null;
    return WebPaneCloseEventArgsDetailDescriptionMetadata;
})();
